The Homebrew Computer Club 38th Reunion: Inspiration To Try A Variant - Tantek

1. - ←
   - →

   # The Homebrew Computer Club 38th Reunion: Inspiration To Try A Variant

   21:36 on 2013-11-18 (ttk.me b/4T71)

   Last Monday night I attended the Homebrew Computer Club 38th Reunion and got to hear Steve Wozniak give an impromptu speech from the heart. It was both inspiring and reminded me of many of the reasons I developed a passion for computers in the first place.

   In reflecting on my notes from his speech, I realized that everything that Woz said about how the Homebrew Computer Club from the start about your "own machine" or your "own computer" applies today nearly 40 years later to your own online identity and your own website.

   However, like the early 1970s, the dominant computing paradigm is once again stuck in a timesharing mindset, updated with new terms and prettier interfaces.

   You may "own" your own handheld machine and computer, but your software and data are more and more updated, controlled, and stored in one or more proprietary centralized "clouds" (whether Google's Gmail/Calendar/Documents, or Apple's iCloud, or Facebook, or others vying to replace them).

   You used to be able to buy two Apple devices, e.g. an iPad/iPod/iPhone and a Mac, and sync them directly with each other. However, as of the latest version of Apple's operating system, ironically named "Mavericks", you can no longer do so, and must sync them both with iCloud, which they treat as the "true" copy of your data:

   > [...] If you use OS X Mavericks v.10.9 or later, your contacts, calendars, and other info are updated on your computers and iOS devices via iCloud. [...]

   Stuck somewhere without an internet connection, or a connection that is slow or unreliable?

   Too bad, you can no longer sync between the devices that you hold in your hand, despite physically connecting them to each other with a cable. You are blocked from syncing the data between the devices in your very hands.

   Last week Woz said:

   > We all wanted to be close to our own machine.

   If our machines are where we store (and share) our data, we are getting further from our machines, not closer.

   The timesharing systems of the 1970s were not disrupted overnight. Nor were they disrupted by large corporations no matter how innovative they thought they were. Nor were they disrupted by first designing for every user.

   They were disrupted by the emergence of innovations from a small group of dedicated enthusiasts who were first looking to empower each other, and second empower others. Woz continued:

   > We wanted to own our own computer.

   > You were going to go into your company, and take your own machine.

   > Everybody was going to be empowered and a master of their own life.

   So what was it about the Homebrew Computer Club that made so much possible? Was it the timing - 1975-03-05? The Silicon Valley location(s)? The people? The frequency of meetings? The structure - how Lee Felsenstein ran the meetings?

   At the 38th reunion I had the chance to catch up with Chris Espinosa, a frequent attendee of Homebrew Computer Club meetings, and asked him about some of the details.

   What time was the meeting?
     Right after work [7pm according to first issue of HCC newsletter]
   How often did they meet?
     Every two weeks. Often enough for a growing sense of continuity, yet infrequent enough to encourage going rather than skipping to go "next week".
   What was the general structure?
     Lee would start the meeting with a microphone, and then given the microphone to anyone who raised their hand with a point to make, or a question to ask. After that there was the "random access" period where people would break off and have smaller discussions, and eventually leave and go get something to eat, like at The Oasis in Palo Alto, or Bob's Big Boy in Cupertino (especially if you were under 21 [which Chris was at the time]).

   For a few years now we've had another growing community, focused on owning your own online identity and data. Primarily online with a wiki and IRC channel, we've also had a strong in-person component, meeting annually in various cities on weekends, and sometimes for evening dinners.

   Hearing the speeches at the Homebrew reunion and speaking with Chris made me wonder: what if we cloned some aspects of the Homebrew Computer Club and created an equivalent for personal websites?

   - We want to own our own web identity and data.
   - We all want to be close to our machines, content, identities.
   - Imagine going into a company, not only with your own machine(s), but your own online identity, document storage, etc.
   - We want to make tools that make us and eventually everyone a master of their own life.

   I mentioned these parallels to Ben Werdmuller and he said it made complete sense to him as well.

   So we're doing this. Started with inspiration, re-using much of the HCC structure, yet without asking permission:

   What
     The Homebrew Website Club
   Who

     Are you building your own website? Indie reader? Personal publishing web app? Or some other digital magic-cloud proxy?

     If so, you might like to come to a gathering of people with likeminded interests. Exchange information, swap ideas, talk shop, help work on a project, whatever... (copied and modified from issue 1).

   When
     18:30-19:30 every other Wednesday night, starting 2013-11-20
   Where (Updated!)
     MozillaSF 7th floor in San Francisco (transit BART:Embarcadero, MUNI:Embarcadero&Folsom).

   I really liked the "mapping" and "random access" meeting phases that Lee Felsenstein came up with. Perhaps we'll adopt similar phases like 30 minutes of "broadcasting" (for anyone to show what they've got working, or ask an open question for help with something) and 30 minutes of "peer to peer".

   I also remember someone at the reunion relating how when someone with the microphone went too long, Lee would cut them off and pass the mic to another person. We'll have to see how much such explicit "blowhard" management is needed. Maybe we just timebox "broadcasting" to 30 min total, and 2 minutes per person? Or maybe we'll figure it out as we go.

   Chris Espinosa's description about how the Homebrew meetings were "right after work" stuck with me. This meant the meetings were something you could go to before other plans, leaving the rest of the evening free to fork off in smaller groups for food, or seeing other friends, or going to home to spend time with the family. Such timing provides greater flexibility for a broader set of people who may have other evening obligations. Ben and I have decided to try starting at 18:30 and see how that goes. We figure you should all be leaving work by 18:00 anyway (regardless of what you do), leaving 30 minutes for transit.

   Once we've confirmed a venue (we have), I'll update this post (updated) and post an update. Until then, put it in your calendar:

   - 18:30 on Wednesday 2013-11-20 @MozSF: Homebrew Website Club

   Be seeing you.

   Thanks to Joël Franusic and Ben Werdmuller for reviewing drafts of this post.